hendrics package
================

Submodules
----------

hendrics.base module
--------------------

.. automodule:: hendrics.base
    :members:
    :undoc-members:
    :show-inheritance:

hendrics.binary module
----------------------

.. automodule:: hendrics.binary
    :members:
    :undoc-members:
    :show-inheritance:

hendrics.calibrate module
-------------------------

.. automodule:: hendrics.calibrate
    :members:
    :undoc-members:
    :show-inheritance:

hendrics.colors module
----------------------

.. automodule:: hendrics.colors
    :members:
    :undoc-members:
    :show-inheritance:

hendrics.create_gti module
--------------------------

.. automodule:: hendrics.create_gti
    :members:
    :undoc-members:
    :show-inheritance:

hendrics.efsearch module
------------------------

.. automodule:: hendrics.efsearch
    :members:
    :undoc-members:
    :show-inheritance:

hendrics.exvar module
---------------------

.. automodule:: hendrics.exvar
    :members:
    :undoc-members:
    :show-inheritance:

hendrics.exposure module
------------------------

.. automodule:: hendrics.exposure
    :members:
    :undoc-members:
    :show-inheritance:

hendrics.fake module
--------------------

.. automodule:: hendrics.fake
    :members:
    :undoc-members:
    :show-inheritance:

hendrics.fspec module
---------------------

.. automodule:: hendrics.fspec
    :members:
    :undoc-members:
    :show-inheritance:

hendrics.io module
------------------

.. automodule:: hendrics.io
    :members:
    :undoc-members:
    :show-inheritance:

hendrics.lcurve module
----------------------

.. automodule:: hendrics.lcurve
    :members:
    :undoc-members:
    :show-inheritance:

hendrics.modeling module
------------------------

.. automodule:: hendrics.modeling
    :members:
    :undoc-members:
    :show-inheritance:

hendrics.plot module
--------------------

.. automodule:: hendrics.plot
    :members:
    :undoc-members:
    :show-inheritance:

hendrics.read_events module
---------------------------

.. automodule:: hendrics.read_events
    :members:
    :undoc-members:
    :show-inheritance:

hendrics.rebin module
---------------------

.. automodule:: hendrics.rebin
    :members:
    :undoc-members:
    :show-inheritance:

hendrics.save_as_xspec module
-----------------------------

.. automodule:: hendrics.save_as_xspec
    :members:
    :undoc-members:
    :show-inheritance:

hendrics.sum_fspec module
-------------------------

.. automodule:: hendrics.sum_fspec
    :members:
    :undoc-members:
    :show-inheritance:

hendrics.timelags module
------------------------

.. automodule:: hendrics.timelags
    :members:
    :undoc-members:
    :show-inheritance:

hendrics.version module
-----------------------

.. automodule:: hendrics.version
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: hendrics
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:
